# coding: utf-8

"""
    ThousandEyes for OpenTelemetry API

    ThousandEyes for OpenTelemetry provides machine-to-machine integration between ThousandEyes and its customers. It allows you to export ThousandEyes telemetry data in OTel format, which is widely used in the industry. With ThousandEyes for OTel, you can leverage frameworks widely used in the observability domain - such as Splunk, Grafana, and Honeycomb - to capture and analyze ThousandEyes data. Any client that supports OTel can use ThousandEyes for OpenTelemetry.  ThousandEyes for OTel is made up of the following components:  * Data streaming APIs that you can use to configure and enable your ThousandEyes tests with OTel-compatible streams, in particular to configure how ThousandEyes telemetry data is exported to client integrations. * A set of streaming pipelines called _collectors_ that actively fetch ThousandEyes network test data, enrich the data with some additional detail, filter, and push the data to the customer-configured endpoints, depending on what you configure via the public APIs. * Third-party OTel collectors that receive, transform, filter, and export different metrics to client applications such as AppD, or any other OTel-capable client configuration.  For more information about ThousandEyes for OpenTelemetry, see the [documentation](https://docs.thousandeyes.com/product-documentation/api/opentelemetry). 

    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from thousandeyes_sdk.streaming.models.audit_operation import AuditOperation
from thousandeyes_sdk.streaming.models.data_model_version import DataModelVersion
from thousandeyes_sdk.streaming.models.endpoint_type import EndpointType
from thousandeyes_sdk.streaming.models.exporter_config import ExporterConfig
from thousandeyes_sdk.streaming.models.filters import Filters
from thousandeyes_sdk.streaming.models.stream_links import StreamLinks
from thousandeyes_sdk.streaming.models.stream_type import StreamType
from thousandeyes_sdk.streaming.models.tag_match import TagMatch
from thousandeyes_sdk.streaming.models.test_match import TestMatch
from typing import Optional, Set
from typing_extensions import Self

class CreateStreamResponse(BaseModel):
    """
    CreateStreamResponse
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="The data stream ID")
    enabled: Optional[StrictBool] = Field(default=None, description="Flag to enable or disable the stream integration.")
    links: Optional[StreamLinks] = Field(default=None, alias="_links")
    type: Optional[StreamType] = None
    endpoint_type: Optional[EndpointType] = Field(default=None, alias="endpointType")
    stream_endpoint_url: Optional[StrictStr] = Field(default=None, description="The URL ThousandEyes sends data stream to. For a URL to be valid, it needs to: - Be syntactically correct. - Be reachable. - Use the HTTPS protocol. - When using the `grpc` endpointType, streamEndpointUrl cannot contain paths:     - Valid . `grpc` - `https://example.com`     - Invalid . `grpc` - `https://example.com/collector`.     - Valid . `http` - `https://example.com/collector`.      - When using the `http` endpointType, the operation must match the exact final full URL (including the path if there is one) to which the metrics will be sent. Examples below:     - `https://api.honeycomb.io:443/v1/metrics`     - `https://ingest.eu0.signalfx.com/v2/datapoint/otlp`", alias="streamEndpointUrl")
    data_model_version: Optional[DataModelVersion] = Field(default=None, alias="dataModelVersion")
    custom_headers: Optional[Dict[str, StrictStr]] = Field(default=None, description="Custom headers. **Note**: When using the `splunk-hec` `type`, the `customHeaders` must contain just one element with the key `token` and the value of the *Splunk HEC Token*.", alias="customHeaders")
    tag_match: Optional[List[TagMatch]] = Field(default=None, description="A collection of tags that determine what tests are included in the data stream. These tag values are also included as attributes in the data stream metrics.", alias="tagMatch")
    test_match: Optional[List[TestMatch]] = Field(default=None, description="A collection of tests to be included in the data stream.", alias="testMatch")
    filters: Optional[Filters] = None
    exporter_config: Optional[ExporterConfig] = Field(default=None, alias="exporterConfig")
    audit_operation: Optional[AuditOperation] = Field(default=None, alias="auditOperation")
    __properties: ClassVar[List[str]] = ["id", "enabled", "_links", "type", "endpointType", "streamEndpointUrl", "dataModelVersion", "customHeaders", "tagMatch", "testMatch", "filters", "exporterConfig", "auditOperation"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        extra="allow",
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return self.model_dump_json(by_alias=True, exclude_unset=True, exclude_none=True)

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateStreamResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of links
        if self.links:
            _dict['_links'] = self.links.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in tag_match (list)
        _items = []
        if self.tag_match:
            for _item in self.tag_match:
                if _item:
                    _items.append(_item.to_dict())
            _dict['tagMatch'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in test_match (list)
        _items = []
        if self.test_match:
            for _item in self.test_match:
                if _item:
                    _items.append(_item.to_dict())
            _dict['testMatch'] = _items
        # override the default output from pydantic by calling `to_dict()` of filters
        if self.filters:
            _dict['filters'] = self.filters.to_dict()
        # override the default output from pydantic by calling `to_dict()` of exporter_config
        if self.exporter_config:
            _dict['exporterConfig'] = self.exporter_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of audit_operation
        if self.audit_operation:
            _dict['auditOperation'] = self.audit_operation.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateStreamResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "enabled": obj.get("enabled"),
            "_links": StreamLinks.from_dict(obj["_links"]) if obj.get("_links") is not None else None,
            "type": obj.get("type"),
            "endpointType": obj.get("endpointType"),
            "streamEndpointUrl": obj.get("streamEndpointUrl"),
            "dataModelVersion": obj.get("dataModelVersion"),
            "customHeaders": obj.get("customHeaders"),
            "tagMatch": [TagMatch.from_dict(_item) for _item in obj["tagMatch"]] if obj.get("tagMatch") is not None else None,
            "testMatch": [TestMatch.from_dict(_item) for _item in obj["testMatch"]] if obj.get("testMatch") is not None else None,
            "filters": Filters.from_dict(obj["filters"]) if obj.get("filters") is not None else None,
            "exporterConfig": ExporterConfig.from_dict(obj["exporterConfig"]) if obj.get("exporterConfig") is not None else None,
            "auditOperation": AuditOperation.from_dict(obj["auditOperation"]) if obj.get("auditOperation") is not None else None
        })
        return _obj





# coding: utf-8

"""
    ThousandEyes for OpenTelemetry API

    ThousandEyes for OpenTelemetry provides machine-to-machine integration between ThousandEyes and its customers. It allows you to export ThousandEyes telemetry data in OTel format, which is widely used in the industry. With ThousandEyes for OTel, you can leverage frameworks widely used in the observability domain - such as Splunk, Grafana, and Honeycomb - to capture and analyze ThousandEyes data. Any client that supports OTel can use ThousandEyes for OpenTelemetry.  ThousandEyes for OTel is made up of the following components:  * Data streaming APIs that you can use to configure and enable your ThousandEyes tests with OTel-compatible streams, in particular to configure how ThousandEyes telemetry data is exported to client integrations. * A set of streaming pipelines called _collectors_ that actively fetch ThousandEyes network test data, enrich the data with some additional detail, filter, and push the data to the customer-configured endpoints, depending on what you configure via the public APIs. * Third-party OTel collectors that receive, transform, filter, and export different metrics to client applications such as AppD, or any other OTel-capable client configuration.  For more information about ThousandEyes for OpenTelemetry, see the [documentation](https://docs.thousandeyes.com/product-documentation/api/opentelemetry). 

    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import unittest
import thousandeyes_sdk.streaming.models

from .test_utils import assert_constructed_model_matches_example_json
from thousandeyes_sdk.streaming.api.streaming_api import StreamingApi


class TestStreamingApi(unittest.TestCase):
    """StreamingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StreamingApi()

    def tearDown(self) -> None:
        pass

    def test_create_stream_models_validation(self) -> None:
        """Test case for create_stream request and response models"""
        request_body_json = """
                {
                  "testMatch" : [ {
                    "id" : "1234",
                    "domain" : "cea"
                  }, {
                    "id" : "5678",
                    "domain" : "endpoint"
                  } ],
                  "endpointType" : "grpc",
                  "streamEndpointUrl" : "https://api.thousandeyes.otel-collector",
                  "exporterConfig" : {
                    "splunkHec" : {
                      "sourceType" : "ThousandEyesOTel",
                      "index" : "thousandeyes_otel_events_index",
                      "source" : "ThousandEyesOTel",
                      "token" : "d0a91307-be2f-4218-a9f8-71c02d98846b"
                    }
                  },
                  "tagMatch" : [ {
                    "key" : "keyA",
                    "value" : "valueA"
                  }, {
                    "key" : "keyB",
                    "value" : "valueB"
                  } ],
                  "filters" : {
                    "testTypes" : {
                      "values" : [ "agent-to-server", "bgp", "http-server" ]
                    }
                  },
                  "type" : "opentelemetry",
                  "dataModelVersion" : "v2",
                  "customHeaders" : {
                    "Authorization" : "*****",
                    "Content-Type" : "*****"
                  },
                  "enabled" : true
                }"""

        request_loaded_json = json.loads(request_body_json)
        request_from_json = thousandeyes_sdk.streaming.models.Stream.from_json(request_body_json)
        assert_constructed_model_matches_example_json(request_from_json, request_loaded_json)

        response_body_json = """
                {
                  "endpointType" : "grpc",
                  "_links" : {
                    "self" : {
                      "href" : "https://api.thousandeyes.com/v7/streams/575766da-9664-4e85-94fe-facbe1154799"
                    }
                  },
                  "streamEndpointUrl" : "https://api.thousandeyes.otel-collector",
                  "exporterConfig" : {
                    "splunkHec" : {
                      "sourceType" : "ThousandEyesOTel",
                      "index" : "thousandeyes_otel_events_index",
                      "source" : "ThousandEyesOTel",
                      "token" : "d0a91307-be2f-4218-a9f8-71c02d98846b"
                    }
                  },
                  "filters" : {
                    "testTypes" : {
                      "values" : [ "agent-to-server", "bgp", "http-server" ]
                    }
                  },
                  "type" : "opentelemetry",
                  "enabled" : true,
                  "dataModelVersion" : "v2",
                  "testMatch" : [ {
                    "id" : "1234",
                    "domain" : "cea"
                  }, {
                    "id" : "5678",
                    "domain" : "endpoint"
                  } ],
                  "tagMatch" : [ {
                    "key" : "keyA",
                    "value" : "valueA"
                  }, {
                    "key" : "keyB",
                    "value" : "valueB"
                  } ],
                  "id" : "342ieu09",
                  "auditOperation" : {
                    "createdDate" : 1679677853573,
                    "createdBy" : 3962
                  },
                  "customHeaders" : {
                    "Authorization" : "*****",
                    "Content-Type" : "*****"
                  }
                }"""

        response_loaded_json = json.loads(response_body_json)
        response_from_json = thousandeyes_sdk.streaming.models.CreateStreamResponse.from_json(response_body_json)
        assert_constructed_model_matches_example_json(response_from_json, response_loaded_json)

    def test_delete_stream_models_validation(self) -> None:
        """Test case for delete_stream request and response models"""


    def test_get_stream_models_validation(self) -> None:
        """Test case for get_stream request and response models"""

        response_body_json = """
                {
                  "endpointType" : "grpc",
                  "_links" : {
                    "self" : {
                      "href" : "https://api.thousandeyes.com/v7/streams/575766da-9664-4e85-94fe-facbe1154799"
                    }
                  },
                  "streamEndpointUrl" : "https://api.thousandeyes.otel-collector",
                  "exporterConfig" : {
                    "splunkHec" : {
                      "sourceType" : "ThousandEyesOTel",
                      "index" : "thousandeyes_otel_events_index",
                      "source" : "ThousandEyesOTel",
                      "token" : "d0a91307-be2f-4218-a9f8-71c02d98846b"
                    }
                  },
                  "filters" : {
                    "testTypes" : {
                      "values" : [ "agent-to-server", "bgp", "http-server" ]
                    }
                  },
                  "type" : "opentelemetry",
                  "enabled" : true,
                  "dataModelVersion" : "v2",
                  "testMatch" : [ {
                    "id" : "1234",
                    "domain" : "cea"
                  }, {
                    "id" : "5678",
                    "domain" : "endpoint"
                  } ],
                  "tagMatch" : [ {
                    "key" : "keyA",
                    "value" : "valueA"
                  }, {
                    "key" : "keyB",
                    "value" : "valueB"
                  } ],
                  "id" : "342ieu09",
                  "auditOperation" : {
                    "createdDate" : 1679677853573,
                    "updatedBy" : 3962,
                    "createdBy" : 3962,
                    "updatedDate" : 1679677853573
                  },
                  "customHeaders" : {
                    "Authorization" : "*****",
                    "Content-Type" : "*****"
                  }
                }"""

        response_loaded_json = json.loads(response_body_json)
        response_from_json = thousandeyes_sdk.streaming.models.GetStreamResponse.from_json(response_body_json)
        assert_constructed_model_matches_example_json(response_from_json, response_loaded_json)

    def test_get_streams_models_validation(self) -> None:
        """Test case for get_streams request and response models"""

        response_body_json = """
                [ {
                  "endpointType" : "grpc",
                  "_links" : {
                    "self" : {
                      "href" : "https://api.thousandeyes.com/v7/streams/575766da-9664-4e85-94fe-facbe1154799"
                    }
                  },
                  "streamEndpointUrl" : "https://api.thousandeyes.otel-collector",
                  "exporterConfig" : {
                    "splunkHec" : {
                      "sourceType" : "ThousandEyesOTel",
                      "index" : "thousandeyes_otel_events_index",
                      "source" : "ThousandEyesOTel",
                      "token" : "d0a91307-be2f-4218-a9f8-71c02d98846b"
                    }
                  },
                  "filters" : {
                    "testTypes" : {
                      "values" : [ "agent-to-server", "bgp", "http-server" ]
                    }
                  },
                  "type" : "opentelemetry",
                  "enabled" : true,
                  "dataModelVersion" : "v2",
                  "testMatch" : [ {
                    "id" : "1234",
                    "domain" : "cea"
                  }, {
                    "id" : "5678",
                    "domain" : "endpoint"
                  } ],
                  "tagMatch" : [ {
                    "key" : "keyA",
                    "value" : "valueA"
                  }, {
                    "key" : "keyB",
                    "value" : "valueB"
                  } ],
                  "id" : "342ieu09",
                  "auditOperation" : {
                    "createdDate" : 1679677853573,
                    "updatedBy" : 3962,
                    "createdBy" : 3962,
                    "updatedDate" : 1679677853573
                  },
                  "customHeaders" : {
                    "Authorization" : "*****",
                    "Content-Type" : "*****"
                  }
                }, {
                  "endpointType" : "grpc",
                  "_links" : {
                    "self" : {
                      "href" : "https://api.thousandeyes.com/v7/streams/575766da-9664-4e85-94fe-facbe1154799"
                    }
                  },
                  "streamEndpointUrl" : "https://api.thousandeyes.otel-collector",
                  "exporterConfig" : {
                    "splunkHec" : {
                      "sourceType" : "ThousandEyesOTel",
                      "index" : "thousandeyes_otel_events_index",
                      "source" : "ThousandEyesOTel",
                      "token" : "d0a91307-be2f-4218-a9f8-71c02d98846b"
                    }
                  },
                  "filters" : {
                    "testTypes" : {
                      "values" : [ "agent-to-server", "bgp", "http-server" ]
                    }
                  },
                  "type" : "opentelemetry",
                  "enabled" : true,
                  "dataModelVersion" : "v2",
                  "testMatch" : [ {
                    "id" : "1234",
                    "domain" : "cea"
                  }, {
                    "id" : "5678",
                    "domain" : "endpoint"
                  } ],
                  "tagMatch" : [ {
                    "key" : "keyA",
                    "value" : "valueA"
                  }, {
                    "key" : "keyB",
                    "value" : "valueB"
                  } ],
                  "id" : "342ieu09",
                  "auditOperation" : {
                    "createdDate" : 1679677853573,
                    "updatedBy" : 3962,
                    "createdBy" : 3962,
                    "updatedDate" : 1679677853573
                  },
                  "customHeaders" : {
                    "Authorization" : "*****",
                    "Content-Type" : "*****"
                  }
                } ]"""

        response_loaded_json = json.loads(response_body_json)
        response_from_dict = [thousandeyes_sdk.streaming.models.GetStreamResponse.from_dict(value) for value in response_loaded_json]
        self.assertGreater(response_from_dict.__len__(), 0)
        for index, element in enumerate(response_from_dict):
            self.assertIsNotNone(element)
            assert_constructed_model_matches_example_json(element, response_loaded_json[index])

    def test_update_stream_models_validation(self) -> None:
        """Test case for update_stream request and response models"""
        request_body_json = """
                {
                  "testMatch" : [ {
                    "id" : "1234",
                    "domain" : "cea"
                  }, {
                    "id" : "5678",
                    "domain" : "endpoint"
                  } ],
                  "exporterConfig" : {
                    "splunkHec" : {
                      "sourceType" : "ThousandEyesOTel",
                      "index" : "thousandeyes_otel_events_index",
                      "source" : "ThousandEyesOTel",
                      "token" : "d0a91307-be2f-4218-a9f8-71c02d98846b"
                    }
                  },
                  "tagMatch" : [ {
                    "key" : "keyA",
                    "value" : "valueA"
                  }, {
                    "key" : "keyB",
                    "value" : "valueB"
                  } ],
                  "filters" : {
                    "testTypes" : {
                      "values" : [ "agent-to-server", "bgp", "http-server" ]
                    }
                  },
                  "customHeaders" : {
                    "Authorization" : "*****",
                    "Content-Type" : "*****"
                  },
                  "enabled" : true
                }"""

        request_loaded_json = json.loads(request_body_json)
        request_from_json = thousandeyes_sdk.streaming.models.PutStream.from_json(request_body_json)
        assert_constructed_model_matches_example_json(request_from_json, request_loaded_json)

        response_body_json = """
                {
                  "endpointType" : "grpc",
                  "_links" : {
                    "self" : {
                      "href" : "https://api.thousandeyes.com/v7/streams/575766da-9664-4e85-94fe-facbe1154799"
                    }
                  },
                  "streamEndpointUrl" : "https://api.thousandeyes.otel-collector",
                  "exporterConfig" : {
                    "splunkHec" : {
                      "sourceType" : "ThousandEyesOTel",
                      "index" : "thousandeyes_otel_events_index",
                      "source" : "ThousandEyesOTel",
                      "token" : "d0a91307-be2f-4218-a9f8-71c02d98846b"
                    }
                  },
                  "filters" : {
                    "testTypes" : {
                      "values" : [ "agent-to-server", "bgp", "http-server" ]
                    }
                  },
                  "type" : "opentelemetry",
                  "enabled" : true,
                  "dataModelVersion" : "v2",
                  "testMatch" : [ {
                    "id" : "1234",
                    "domain" : "cea"
                  }, {
                    "id" : "5678",
                    "domain" : "endpoint"
                  } ],
                  "tagMatch" : [ {
                    "key" : "keyA",
                    "value" : "valueA"
                  }, {
                    "key" : "keyB",
                    "value" : "valueB"
                  } ],
                  "id" : "342ieu09",
                  "auditOperation" : {
                    "createdDate" : 1679677853573,
                    "updatedBy" : 3962,
                    "createdBy" : 3962,
                    "updatedDate" : 1679677853573
                  },
                  "customHeaders" : {
                    "Authorization" : "*****",
                    "Content-Type" : "*****"
                  }
                }"""

        response_loaded_json = json.loads(response_body_json)
        response_from_json = thousandeyes_sdk.streaming.models.GetStreamResponse.from_json(response_body_json)
        assert_constructed_model_matches_example_json(response_from_json, response_loaded_json)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    ThousandEyes for OpenTelemetry API

    ThousandEyes for OpenTelemetry provides machine-to-machine integration between ThousandEyes and its customers. It allows you to export ThousandEyes telemetry data in OTel format, which is widely used in the industry. With ThousandEyes for OTel, you can leverage frameworks widely used in the observability domain - such as Splunk, Grafana, and Honeycomb - to capture and analyze ThousandEyes data. Any client that supports OTel can use ThousandEyes for OpenTelemetry.  ThousandEyes for OTel is made up of the following components:  * Data streaming APIs that you can use to configure and enable your ThousandEyes tests with OTel-compatible streams, in particular to configure how ThousandEyes telemetry data is exported to client integrations. * A set of streaming pipelines called _collectors_ that actively fetch ThousandEyes network test data, enrich the data with some additional detail, filter, and push the data to the customer-configured endpoints, depending on what you configure via the public APIs. * Third-party OTel collectors that receive, transform, filter, and export different metrics to client applications such as AppD, or any other OTel-capable client configuration.  For more information about ThousandEyes for OpenTelemetry, see the [documentation](https://docs.thousandeyes.com/product-documentation/api/opentelemetry). 

    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from thousandeyes_sdk.streaming.models.api_error import ApiError
from thousandeyes_sdk.streaming.models.api_error_integration_limits import ApiErrorIntegrationLimits
from thousandeyes_sdk.streaming.models.audit_operation import AuditOperation
from thousandeyes_sdk.streaming.models.audit_operation_with_update import AuditOperationWithUpdate
from thousandeyes_sdk.streaming.models.bad_request_error import BadRequestError
from thousandeyes_sdk.streaming.models.create_stream_response import CreateStreamResponse
from thousandeyes_sdk.streaming.models.data_model_version import DataModelVersion
from thousandeyes_sdk.streaming.models.endpoint_type import EndpointType
from thousandeyes_sdk.streaming.models.exporter_config import ExporterConfig
from thousandeyes_sdk.streaming.models.exporter_config_splunk_hec import ExporterConfigSplunkHec
from thousandeyes_sdk.streaming.models.filters import Filters
from thousandeyes_sdk.streaming.models.filters_test_types import FiltersTestTypes
from thousandeyes_sdk.streaming.models.get_stream_response import GetStreamResponse
from thousandeyes_sdk.streaming.models.put_stream import PutStream
from thousandeyes_sdk.streaming.models.stream import Stream
from thousandeyes_sdk.streaming.models.stream_links import StreamLinks
from thousandeyes_sdk.streaming.models.stream_response import StreamResponse
from thousandeyes_sdk.streaming.models.stream_self_link import StreamSelfLink
from thousandeyes_sdk.streaming.models.stream_type import StreamType
from thousandeyes_sdk.streaming.models.tag_match import TagMatch
from thousandeyes_sdk.streaming.models.tag_match_object_type import TagMatchObjectType
from thousandeyes_sdk.streaming.models.test_match import TestMatch
from thousandeyes_sdk.streaming.models.test_match_domain import TestMatchDomain
from thousandeyes_sdk.streaming.models.test_type import TestType
from thousandeyes_sdk.streaming.models.unauthorized_error import UnauthorizedError



# coding: utf-8

"""
    ThousandEyes for OpenTelemetry API

    ThousandEyes for OpenTelemetry provides machine-to-machine integration between ThousandEyes and its customers. It allows you to export ThousandEyes telemetry data in OTel format, which is widely used in the industry. With ThousandEyes for OTel, you can leverage frameworks widely used in the observability domain - such as Splunk, Grafana, and Honeycomb - to capture and analyze ThousandEyes data. Any client that supports OTel can use ThousandEyes for OpenTelemetry.  ThousandEyes for OTel is made up of the following components:  * Data streaming APIs that you can use to configure and enable your ThousandEyes tests with OTel-compatible streams, in particular to configure how ThousandEyes telemetry data is exported to client integrations. * A set of streaming pipelines called _collectors_ that actively fetch ThousandEyes network test data, enrich the data with some additional detail, filter, and push the data to the customer-configured endpoints, depending on what you configure via the public APIs. * Third-party OTel collectors that receive, transform, filter, and export different metrics to client applications such as AppD, or any other OTel-capable client configuration.  For more information about ThousandEyes for OpenTelemetry, see the [documentation](https://docs.thousandeyes.com/product-documentation/api/opentelemetry). 

    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from thousandeyes_sdk.streaming.models.test_type import TestType
from typing import Optional, Set
from typing_extensions import Self

class FiltersTestTypes(BaseModel):
    """
    Test types that can be used for filtering data points.
    """ # noqa: E501
    values: Optional[List[TestType]] = Field(default=None, description="A list of test types to filter data points.")
    __properties: ClassVar[List[str]] = ["values"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        extra="allow",
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return self.model_dump_json(by_alias=True, exclude_unset=True, exclude_none=True)

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FiltersTestTypes from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FiltersTestTypes from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "values": obj.get("values")
        })
        return _obj





# coding: utf-8

"""
    ThousandEyes for OpenTelemetry API

    ThousandEyes for OpenTelemetry provides machine-to-machine integration between ThousandEyes and its customers. It allows you to export ThousandEyes telemetry data in OTel format, which is widely used in the industry. With ThousandEyes for OTel, you can leverage frameworks widely used in the observability domain - such as Splunk, Grafana, and Honeycomb - to capture and analyze ThousandEyes data. Any client that supports OTel can use ThousandEyes for OpenTelemetry.  ThousandEyes for OTel is made up of the following components:  * Data streaming APIs that you can use to configure and enable your ThousandEyes tests with OTel-compatible streams, in particular to configure how ThousandEyes telemetry data is exported to client integrations. * A set of streaming pipelines called _collectors_ that actively fetch ThousandEyes network test data, enrich the data with some additional detail, filter, and push the data to the customer-configured endpoints, depending on what you configure via the public APIs. * Third-party OTel collectors that receive, transform, filter, and export different metrics to client applications such as AppD, or any other OTel-capable client configuration.  For more information about ThousandEyes for OpenTelemetry, see the [documentation](https://docs.thousandeyes.com/product-documentation/api/opentelemetry). 

    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class DataModelVersion(str, Enum):
    """
    The version of the data model used in the data stream. Default: `v2`
    """

    """
    allowed enum values
    """
    V1 = 'v1'
    V2 = 'v2'
    UNKNOWN = 'unknown'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DataModelVersion from a JSON string"""
        return cls(json.loads(json_str))

    @classmethod
    def _missing_(cls, value):
        """Handle unknown values"""
        return cls.UNKNOWN

